FQE
===================
This module implements the fitted Q evaluation algorithm for offline policy evaluation.

.. code::

   from cfrl import fqe

.. automodule:: cfrl.fqe
   :members:
   :show-inheritance:
   :special-members: __init__